#!/bin/sh
##
##
## simple twitter spider
## -- generate graphs from twitter friendships
##
## version:	0.1
## author:	BeF <bef@pentaphase.de>
## date:	2007-03-16
## license:	GPLv2 - see http://www.gnu.org/licenses/gpl.html
##
##
##
# the next line restarts using tclsh \
exec tclsh "$0" "$@"

source twitterlib.tcl

if {[llength $::argv] != 3} {
	puts "incorrect arguments."
	puts "params: <name> <recursion level> <directed 0/1>"
	exit
}

## options
set center_name [lindex $::argv 0]
set recursions [lindex $::argv 1]
set directed [lindex $::argv 2]

## init
array set tree {}
puts "reading cache..."
read_cache

## recursively spider twitter friends
array set out {}
proc get_tree {start {max 0} {n 0}} {
	global out
	global tree
	puts "checking $start (recursion: $n)"
	check_tree_friend $start
	set out($start) $tree($start)
	if {$n < $max} {
		foreach name $tree($start) {
			get_tree $name $max [expr {$n + 1}]
		}
	}
}

get_tree $center_name $recursions

## eliminate incomplete targets
set names_out [array names out]
foreach key $names_out {
	set newnames {}
	foreach name $out($key) {
		if {[lsearch -exact $names_out $name] != -1} {
			lappend newnames $name
		}
	}
	set out($key) $newnames
}

## dot output
set file_base "${center_name}-${recursions}-${directed}"
set of [open "${file_base}.dot" "w+"]

set next_step_desc ""
if {$directed} {
	## directed graph
	puts $of "digraph nu2m_${center_name}_${recursions} {"
	puts $of "  graph \[ranksep=1.5 splines=true overlap=false label=\"${center_name}'s twitter friendships - recursions: ${recursions}\"\]"
	puts $of "  $center_name \[color=green\];"
	foreach key $names_out {
		puts $of "  $key -> { $out($key) };"
	}
	puts $of "}"

	set next_step_desc "\$ dot -T pdf ${file_base}.dot >${file_base}.pdf"
} else {
	## undirected graph
	puts $of "graph nu2m_${center_name}_${recursions} {"
	puts $of "  graph \[splines=true overlap=false label=\"${center_name}'s twitter friendships - recursions: ${recursions}\"\]"
	puts $of "  $center_name \[color=green\];"
	foreach key $names_out {
		puts $of "  $key -- { $out($key) };"
	}
	puts $of "}"

	set next_step_desc "\$ neato -T pdf ${file_base}.dot >${file_base}.pdf"
}

close $of

puts "****************************************"
puts "the next step could be:"
puts $next_step_desc
puts "****************************************"
